.. bodhi documentation master file, created by
   sphinx-quickstart on Sat Aug 10 09:29:50 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to bodhi's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   man_bodhi
   release_notes
   services


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

